using FitConnect.Models;

namespace FitConnect.Interfaces;

public interface ISender : IFitConnectClient {
    /// <summary>
    ///     Sending a submission
    /// </summary>
    /// <param name="submission">
    ///     The submission to be sent. Use <see cref="SubmissionBuilder" /> to create
    ///     the submission
    /// </param>
    /// <returns></returns>
    Task<SentSubmission> SendAsync(SendableSubmission submission);

    /// <summary>
    ///     Sending a pre-encrypted submission
    /// </summary>
    /// <param name="submission">
    ///     The submission to be sent. Use <see cref="EncryptedSubmissionBuilder" />
    ///     to create the submission
    /// </param>
    /// <returns></returns>
    Task<SentSubmission> SendAsync(SendableEncryptedSubmission submission);
    

    /// <summary>
    ///     Receives the public key for the destination with the id <paramref name="destinationId" />
    /// </summary>
    /// <param name="destinationId">Destination id of the requested public key</param>
    /// <returns></returns>
    Task<string> GetPublicKeyForDestinationAsync(Guid destinationId);

    /// <summary>
    /// Requesting the state of the submission
    /// </summary>
    /// <returns></returns>
    Task<SubmissionStatus> GetStatusForSubmissionAsync(SentSubmission submission);
}
